@@ -6,4 +6,4 @@ Created on Mon Aug 17 08:58:06 2020
 """
 
 from .Park_test import Park_test
-from .Glejser import Glejser
\ No newline at end of file
+from .Glejser import Glejser_test
\ No newline at end of file
